"""
测试图片提取器模块
"""

import os
import tempfile
import unittest
import zipfile
from pathlib import Path

import sys
sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', 'src'))

from docx_image_extractor_mcp.core.extractor import to_ascii_dirname, extract_images, _detect_image_format
from docx_image_extractor_mcp.core.config import Config, DEFAULT_CONFIG


class TestExtractor(unittest.TestCase):
    """测试图片提取器"""
    
    def test_to_ascii_dirname(self):
        """测试文档名转换"""
        # 测试中文转拼音
        self.assertEqual(to_ascii_dirname("测试文档.docx"), "ceshiwendang")
        
        # 测试英文
        self.assertEqual(to_ascii_dirname("test_document.docx"), "testdocument")
        
        # 测试混合
        self.assertEqual(to_ascii_dirname("Test测试123.docx"), "testceshi123")
        
        # 测试特殊字符
        self.assertEqual(to_ascii_dirname("文档-名称_test.docx"), "wendangmingchengtest")
        
        # 测试空字符串
        self.assertEqual(to_ascii_dirname(""), "")
        
        # 测试只有扩展名
        self.assertEqual(to_ascii_dirname(".docx"), "")
    
    def test_extract_images_file_not_exists(self):
        """测试文件不存在的情况"""
        result = extract_images("nonexistent.docx")
        self.assertFalse(result['success'])
        self.assertIn("文档不存在", result['msg'])
        self.assertEqual(result['count'], 0)
    
    def test_extract_images_wrong_extension(self):
        """测试错误的文件扩展名"""
        with tempfile.NamedTemporaryFile(suffix=".txt") as tmp:
            result = extract_images(tmp.name)
            self.assertFalse(result['success'])
            self.assertIn("只支持.docx和.doc文件", result['msg'])
            self.assertEqual(result['count'], 0)
    
    def test_extract_images_invalid_zip(self):
        """测试无效的ZIP文件"""
        with tempfile.NamedTemporaryFile(suffix=".docx", delete=False) as tmp:
            tmp.write(b"invalid zip content")
            tmp.flush()
            tmp_name = tmp.name
            
        try:
            result = extract_images(tmp_name)
            self.assertFalse(result['success'])
            self.assertIn("无效的DOCX文件", result['msg'])
        finally:
            try:
                os.unlink(tmp_name)
            except (OSError, PermissionError):
                pass  # 忽略删除失败
    
    def test_detect_image_format(self):
        """测试图片格式检测"""
        # 创建一个临时ZIP文件用于测试
        with tempfile.NamedTemporaryFile(suffix=".zip", delete=False) as tmp_zip:
            tmp_zip_name = tmp_zip.name
            
        try:
            with zipfile.ZipFile(tmp_zip_name, 'w') as zf:
                # 添加PNG文件头
                zf.writestr("test.png", b'\x89PNG\r\n\x1a\n' + b'fake png data')
                # 添加JPEG文件头
                zf.writestr("test.jpg", b'\xff\xd8\xff\xe0' + b'fake jpg data')
                # 添加未知格式
                zf.writestr("test.unknown", b'unknown format')
            
            with zipfile.ZipFile(tmp_zip_name, 'r') as zf:
                # 测试PNG检测
                self.assertEqual(_detect_image_format(zf, "test.png"), ".png")
                # 测试JPEG检测
                self.assertEqual(_detect_image_format(zf, "test.jpg"), ".jpg")
                # 测试未知格式（应该返回默认的.png）
                self.assertEqual(_detect_image_format(zf, "test.unknown"), ".png")
        finally:
            try:
                os.unlink(tmp_zip_name)
            except (OSError, PermissionError):
                pass  # 忽略删除失败


class TestConfig(unittest.TestCase):
    """测试配置模块"""
    
    def test_default_config(self):
        """测试默认配置"""
        config = Config()
        self.assertEqual(config.base_image_dir, DEFAULT_CONFIG["base_image_dir"])
        self.assertEqual(config.image_naming_prefix, DEFAULT_CONFIG["image_naming"]["prefix"])
        self.assertEqual(config.image_naming_padding, DEFAULT_CONFIG["image_naming"]["padding"])
    
    def test_config_get_set(self):
        """测试配置的获取和设置"""
        config = Config()
        
        # 测试设置和获取
        config.set("test.key", "test_value")
        self.assertEqual(config.get("test.key"), "test_value")
        
        # 测试默认值
        self.assertEqual(config.get("nonexistent.key", "default"), "default")
    
    def test_config_from_dict(self):
        """测试从字典加载配置"""
        config = Config()
        user_config = {
            "base_image_dir": "custom_images",
            "image_naming": {
                "prefix": "pic"
            }
        }
        
        config._merge_config(user_config)
        self.assertEqual(config.base_image_dir, "custom_images")
        self.assertEqual(config.image_naming_prefix, "pic")
        # 确保其他配置保持默认值
        self.assertEqual(config.image_naming_padding, DEFAULT_CONFIG["image_naming"]["padding"])


if __name__ == "__main__":
    unittest.main()


"""
MCP服务器模块
"""

import json
import logging
from typing import List, Dict, Any

from ..core.extractor import extract_images, to_ascii_dirname
from ..core.config import config

logger = logging.getLogger(__name__)


class DocxImageExtractorMCP:
    """DOC/DOCX图片提取器MCP服务"""
    
    def __init__(self):
        try:
            from mcp.server import Server
            from mcp.server.models import InitializationOptions
            from mcp.server import NotificationOptions
            from mcp.types import Tool, TextContent
        except ImportError:
            raise ImportError("需要安装 mcp 库: pip install mcp")
            
        self.server = Server("docx-image-extractor")
        self.Tool = Tool
        self.TextContent = TextContent
        self.InitializationOptions = InitializationOptions
        self.NotificationOptions = NotificationOptions
        self.setup_tools()
        
        logger.info("DOC/DOCX图片提取器MCP服务已初始化")

    def setup_tools(self):
        """设置MCP工具"""
        
        @self.server.list_tools()
        async def handle_list_tools():
            return [
                self.Tool(
                    name="extract_docx_images",
                    description="从Word文档(.docx或.doc)中提取所有图片到指定目录，支持自动命名和格式检测",
                    inputSchema={
                        "type": "object",
                        "properties": {
                            "docx_path": {
                                "type": "string",
                                "description": "Word文档的完整路径（支持.docx和.doc格式）"
                            },
                            "base_image_dir": {
                                "type": "string",
                                "description": "存放图片的根目录名（如 images、assets、pictures等）",
                                "default": config.base_image_dir
                            }
                        },
                        "required": ["docx_path"]
                    }
                ),
                self.Tool(
                    name="preview_docx_structure",
                    description="预览Word文档的内部结构，包括媒体文件信息（仅支持.docx格式）",
                    inputSchema={
                        "type": "object",
                        "properties": {
                            "docx_path": {
                                "type": "string",
                                "description": "Word文档的完整路径（仅支持.docx格式）"
                            }
                        },
                        "required": ["docx_path"]
                    }
                ),
                self.Tool(
                    name="convert_filename_to_ascii",
                    description="将中文文件名转换为ASCII字符（拼音），用于目录命名",
                    inputSchema={
                        "type": "object",
                        "properties": {
                            "filename": {
                                "type": "string",
                                "description": "要转换的文件名"
                            }
                        },
                        "required": ["filename"]
                    }
                )
            ]

        @self.server.call_tool()
        async def handle_call_tool(name: str, arguments: dict):
            try:
                if name == "extract_docx_images":
                    return await self._handle_extract_images(arguments)
                elif name == "preview_docx_structure":
                    return await self._handle_preview_structure(arguments)
                elif name == "convert_filename_to_ascii":
                    return await self._handle_convert_filename(arguments)
                else:
                    return [self.TextContent(type="text", text=f"未知工具: {name}")]
            except Exception as e:
                logger.error(f"工具调用失败 {name}: {e}")
                return [self.TextContent(type="text", text=f"工具执行失败: {str(e)}")]
    
    async def _handle_extract_images(self, arguments: dict) -> List:
        """处理图片提取"""
        docx_path = arguments["docx_path"]
        base_image_dir = arguments.get("base_image_dir", config.base_image_dir)
        
        logger.info(f"开始提取图片: {docx_path}")
        result = extract_images(docx_path, base_image_dir)
        
        # 构建详细的响应消息
        if result['success']:
            response = {
                "status": "success",
                "message": result['msg'],
                "details": {
                    "extracted_count": result['count'],
                    "output_directory": result['output_dir'],
                    "skipped_count": result.get('skipped', 0)
                }
            }
        else:
            response = {
                "status": "error",
                "message": result['msg'],
                "details": {
                    "extracted_count": result.get('count', 0),
                    "output_directory": result.get('output_dir', ''),
                    "skipped_count": result.get('skipped', 0)
                }
            }
        
        return [self.TextContent(type="text", text=json.dumps(response, ensure_ascii=False, indent=2))]
    
    async def _handle_preview_structure(self, arguments: dict) -> List:
        """处理文档结构预览"""
        import zipfile
        import os
        
        docx_path = arguments["docx_path"]
        
        if not os.path.exists(docx_path):
            return [self.TextContent(type="text", text=f"文档不存在: {docx_path}")]
        
        if not docx_path.lower().endswith('.docx'):
            return [self.TextContent(type="text", text="只支持.docx文件")]
        
        try:
            with zipfile.ZipFile(docx_path, 'r') as zip_ref:
                all_files = zip_ref.namelist()
                media_files = [f for f in all_files if f.startswith('word/media/') and not f.endswith('/')]
                
                structure = {
                    "document_path": docx_path,
                    "total_files": len(all_files),
                    "media_files_count": len(media_files),
                    "media_files": []
                }
                
                for media_file in media_files:
                    try:
                        file_info = zip_ref.getinfo(media_file)
                        structure["media_files"].append({
                            "path": media_file,
                            "size": file_info.file_size,
                            "compressed_size": file_info.compress_size
                        })
                    except Exception as e:
                        logger.warning(f"获取文件信息失败 {media_file}: {e}")
                
                return [self.TextContent(type="text", text=json.dumps(structure, ensure_ascii=False, indent=2))]
                
        except Exception as e:
            return [self.TextContent(type="text", text=f"预览文档结构失败: {str(e)}")]
    
    async def _handle_convert_filename(self, arguments: dict) -> List:
        """处理文件名转换"""
        filename = arguments["filename"]
        converted = to_ascii_dirname(filename)
        
        result = {
            "original": filename,
            "converted": converted,
            "message": f"文件名 '{filename}' 转换为 '{converted}'"
        }
        
        return [self.TextContent(type="text", text=json.dumps(result, ensure_ascii=False, indent=2))]

    async def run(self):
        """运行MCP服务器"""
        try:
            from mcp.server.stdio import stdio_server
        except ImportError:
            raise ImportError("需要安装 mcp 库: pip install mcp")
            
        async with stdio_server() as (read_stream, write_stream):
            await self.server.run(
                read_stream,
                write_stream,
                self.InitializationOptions(
                    server_name="docx-image-extractor",
                    server_version="1.0.0",
                    capabilities=self.server.get_capabilities(
                        notification_options=self.NotificationOptions(),
                        experimental_capabilities={}
                    )
                )
            )


"""
核心功能模块
"""

from .extractor import extract_images, to_ascii_dirname, _detect_image_format
from .config import Config, load_config, DEFAULT_CONFIG

__all__ = [
    "extract_images",
    "to_ascii_dirname", 
    "_detect_image_format",
    "Config",
    "load_config",
    "DEFAULT_CONFIG",
]


"""
主入口模块
"""

import asyncio
import sys
from .interfaces.mcp_server import DocxImageExtractorMCP


async def main():
    """主函数"""
    try:
        mcp_service = DocxImageExtractorMCP()
        await mcp_service.run()
    except KeyboardInterrupt:
        print("\n服务已停止")
        sys.exit(0)
    except Exception as e:
        print(f"启动服务失败: {e}")
        sys.exit(1)


def cli_main():
    """命令行入口点"""
    asyncio.run(main())


if __name__ == "__main__":
    cli_main()


"""
配置模块
"""

import os
import json
import logging
from pathlib import Path
from typing import Dict, Any, Optional

# 默认配置
DEFAULT_CONFIG = {
    "base_image_dir": "images",
    "image_naming": {
        "prefix": "image",
        "padding": 3,
        "format": "{prefix}_{index:0{padding}d}{ext}"
    },
    "logging": {
        "level": "INFO",
        "format": "%(asctime)s - %(name)s - %(levelname)s - %(message)s"
    },
    "extraction": {
        "skip_empty_files": True,
        "detect_format": True,
        "supported_formats": [".png", ".jpg", ".jpeg", ".gif", ".bmp", ".webp"]
    }
}


class Config:
    """配置管理类"""
    
    def __init__(self, config_path: Optional[str] = None):
        self._config = DEFAULT_CONFIG.copy()
        self._config_path = config_path
        
        if config_path and os.path.exists(config_path):
            self.load_from_file(config_path)
        
        self._setup_logging()
    
    def load_from_file(self, config_path: str) -> None:
        """从文件加载配置"""
        try:
            with open(config_path, 'r', encoding='utf-8') as f:
                user_config = json.load(f)
            self._merge_config(user_config)
        except Exception as e:
            logging.warning(f"加载配置文件失败: {e}")
    
    def _merge_config(self, user_config: Dict[str, Any]) -> None:
        """合并用户配置"""
        def merge_dict(base: dict, update: dict) -> dict:
            for key, value in update.items():
                if key in base and isinstance(base[key], dict) and isinstance(value, dict):
                    merge_dict(base[key], value)
                else:
                    base[key] = value
            return base
        
        merge_dict(self._config, user_config)
    
    def _setup_logging(self) -> None:
        """设置日志"""
        log_config = self._config.get("logging", {})
        level = getattr(logging, log_config.get("level", "INFO").upper())
        format_str = log_config.get("format", DEFAULT_CONFIG["logging"]["format"])
        
        logging.basicConfig(level=level, format=format_str)
    
    def get(self, key: str, default: Any = None) -> Any:
        """获取配置值"""
        keys = key.split('.')
        value = self._config
        
        for k in keys:
            if isinstance(value, dict) and k in value:
                value = value[k]
            else:
                return default
        
        return value
    
    def set(self, key: str, value: Any) -> None:
        """设置配置值"""
        keys = key.split('.')
        config = self._config
        
        for k in keys[:-1]:
            if k not in config:
                config[k] = {}
            config = config[k]
        
        config[keys[-1]] = value
    
    def save_to_file(self, config_path: Optional[str] = None) -> None:
        """保存配置到文件"""
        path = config_path or self._config_path
        if not path:
            raise ValueError("未指定配置文件路径")
        
        os.makedirs(os.path.dirname(path), exist_ok=True)
        
        with open(path, 'w', encoding='utf-8') as f:
            json.dump(self._config, f, indent=2, ensure_ascii=False)
    
    @property
    def base_image_dir(self) -> str:
        """获取基础图片目录"""
        return self.get("base_image_dir", "images")
    
    @property
    def image_naming_format(self) -> str:
        """获取图片命名格式"""
        naming = self.get("image_naming", {})
        return naming.get("format", "{prefix}_{index:0{padding}d}{ext}")
    
    @property
    def image_naming_prefix(self) -> str:
        """获取图片命名前缀"""
        return self.get("image_naming.prefix", "image")
    
    @property
    def image_naming_padding(self) -> int:
        """获取图片命名填充位数"""
        return self.get("image_naming.padding", 3)
    
    @property
    def supported_formats(self) -> list:
        """获取支持的图片格式"""
        return self.get("extraction.supported_formats", [".png", ".jpg", ".jpeg", ".gif", ".bmp", ".webp"])


# 全局配置实例
config = Config()


def get_config_path() -> str:
    """获取默认配置文件路径"""
    home_dir = Path.home()
    config_dir = home_dir / ".docx-image-extractor"
    config_dir.mkdir(exist_ok=True)
    return str(config_dir / "config.json")


def load_config(config_path: Optional[str] = None) -> Config:
    """加载配置"""
    if config_path is None:
        config_path = get_config_path()
    
    return Config(config_path)


#!/usr/bin/env python3
"""
DOC 支持功能测试脚本
"""

import os
import sys
import tempfile
from pathlib import Path

# 添加项目路径到 Python 路径
project_root = Path(__file__).parent
src_path = project_root / "src"
sys.path.insert(0, str(src_path))

try:
    from docx_image_extractor_mcp.core.extractor import extract_images, to_ascii_dirname
    print("✅ 成功导入核心模块")
except ImportError as e:
    print(f"❌ 导入核心模块失败: {e}")
    sys.exit(1)

def test_ascii_conversion():
    """测试中文文件名转ASCII功能"""
    print("\n🧪 测试中文文件名转ASCII功能...")
    
    test_cases = [
        ("测试文档.docx", "ceshi-wendang"),
        ("项目报告.doc", "xiangmu-baogao"),
        ("会议纪要 2024.docx", "huiyi-jiyao-2024"),
    ]
    
    for original, expected_prefix in test_cases:
        result = to_ascii_dirname(original)
        print(f"  {original} -> {result}")
        if expected_prefix in result:
            print(f"    ✅ 转换成功")
        else:
            print(f"    ❌ 转换失败，期望包含: {expected_prefix}")

def test_file_extension_validation():
    """测试文件扩展名验证"""
    print("\n🧪 测试文件扩展名验证...")
    
    # 创建临时目录
    with tempfile.TemporaryDirectory() as temp_dir:
        temp_path = Path(temp_dir)
        
        # 测试不支持的文件格式
        unsupported_file = temp_path / "test.txt"
        unsupported_file.write_text("test content")
        
        try:
            result = extract_images(str(unsupported_file))
            print(f"    ❌ 应该拒绝不支持的文件格式")
        except Exception as e:
            print(f"    ✅ 正确拒绝不支持的文件格式: {e}")
        
        # 测试不存在的文件
        try:
            result = extract_images("nonexistent.docx")
            print(f"    ❌ 应该拒绝不存在的文件")
        except Exception as e:
            print(f"    ✅ 正确拒绝不存在的文件: {e}")

def test_dependencies():
    """测试依赖项是否正确安装"""
    print("\n🧪 测试依赖项...")
    
    dependencies = [
        ("olefile", "DOC文件支持"),
        ("pypinyin", "中文转拼音"),
        ("zipfile", "DOCX文件支持"),
    ]
    
    for module_name, description in dependencies:
        try:
            if module_name == "zipfile":
                import zipfile
            elif module_name == "olefile":
                import olefile
            elif module_name == "pypinyin":
                import pypinyin
            print(f"    ✅ {description} ({module_name}) 可用")
        except ImportError:
            print(f"    ❌ {description} ({module_name}) 不可用")

def main():
    """主测试函数"""
    print("🚀 开始 DOC/DOCX 图片提取器功能测试")
    print("=" * 50)
    
    test_dependencies()
    test_ascii_conversion()
    test_file_extension_validation()
    
    print("\n" + "=" * 50)
    print("✅ 测试完成！")
    print("\n📝 注意事项:")
    print("  - 要测试实际的图片提取功能，请准备包含图片的DOC/DOCX文件")
    print("  - 使用命令: python -m docx_image_extractor_mcp.interfaces.cli extract your_file.doc")
    print("  - 或者: python -m docx_image_extractor_mcp.interfaces.cli extract your_file.docx")

if __name__ == "__main__":
    main()


#!/usr/bin/env python3
"""
自动化发布脚本
用于将项目发布到 PyPI
"""

import os
import sys
import subprocess
import shutil
from pathlib import Path
import argparse


class PublishManager:
    """发布管理器"""
    
    def __init__(self, project_root: Path):
        self.project_root = project_root
        self.dist_dir = project_root / "dist"
        self.build_dir = project_root / "build"
        
    def run_command(self, cmd: list, check: bool = True) -> subprocess.CompletedProcess:
        """运行命令"""
        print(f"🔧 执行命令: {' '.join(cmd)}")
        try:
            result = subprocess.run(cmd, check=check, capture_output=True, text=True, cwd=self.project_root)
            if result.stdout:
                print(f"✅ 输出: {result.stdout}")
            return result
        except subprocess.CalledProcessError as e:
            print(f"❌ 命令执行失败: {e}")
            if e.stderr:
                print(f"错误信息: {e.stderr}")
            raise
    
    def clean_build_dirs(self):
        """清理构建目录"""
        print("🧹 清理构建目录...")
        
        dirs_to_clean = [
            self.dist_dir,
            self.build_dir,
            self.project_root / "src" / "docx_image_extractor_mcp.egg-info"
        ]
        
        for dir_path in dirs_to_clean:
            if dir_path.exists():
                shutil.rmtree(dir_path)
                print(f"   删除: {dir_path}")
    
    def run_tests(self):
        """运行测试"""
        print("🧪 运行测试...")
        self.run_command([sys.executable, "-m", "pytest", "tests/", "-v"])
    
    def check_tools(self):
        """检查必要工具"""
        print("🔍 检查发布工具...")
        
        tools = ["build", "twine"]
        for tool in tools:
            try:
                self.run_command([sys.executable, "-m", tool, "--version"])
            except subprocess.CalledProcessError:
                print(f"❌ 工具 {tool} 未安装")
                print(f"请运行: pip install {tool}")
                sys.exit(1)
    
    def build_package(self):
        """构建包"""
        print("📦 构建包...")
        self.run_command([sys.executable, "-m", "build"])
        
        # 检查生成的文件
        if not self.dist_dir.exists():
            raise RuntimeError("构建失败：dist 目录不存在")
        
        files = list(self.dist_dir.glob("*"))
        if not files:
            raise RuntimeError("构建失败：没有生成文件")
        
        print("✅ 构建完成，生成文件:")
        for file in files:
            print(f"   {file.name}")
    
    def test_install(self):
        """测试安装"""
        print("🧪 测试本地安装...")
        
        # 查找wheel文件
        wheel_files = list(self.dist_dir.glob("*.whl"))
        if not wheel_files:
            raise RuntimeError("未找到wheel文件")
        
        wheel_file = wheel_files[0]
        
        # 创建临时虚拟环境进行测试
        test_env = self.project_root / "test_env"
        if test_env.exists():
            shutil.rmtree(test_env)
        
        try:
            # 创建虚拟环境
            self.run_command([sys.executable, "-m", "venv", str(test_env)])
            
            # 获取虚拟环境的python路径
            if os.name == 'nt':  # Windows
                venv_python = test_env / "Scripts" / "python.exe"
            else:  # Unix/Linux/Mac
                venv_python = test_env / "bin" / "python"
            
            # 在虚拟环境中安装包
            self.run_command([str(venv_python), "-m", "pip", "install", str(wheel_file)])
            
            # 测试导入
            self.run_command([str(venv_python), "-c", "import docx_image_extractor_mcp; print('导入成功')"])
            
            # 测试命令行工具
            self.run_command([str(venv_python), "-m", "docx_image_extractor_mcp.main", "--help"])
            
            print("✅ 本地安装测试通过")
            
        finally:
            # 清理测试环境
            if test_env.exists():
                shutil.rmtree(test_env)
    
    def upload_to_testpypi(self):
        """上传到测试PyPI"""
        print("🚀 上传到测试PyPI...")
        self.run_command([
            sys.executable, "-m", "twine", "upload",
            "--repository", "testpypi",
            "dist/*"
        ])
    
    def upload_to_pypi(self):
        """上传到正式PyPI"""
        print("🚀 上传到正式PyPI...")
        
        # 确认操作
        response = input("⚠️  确定要发布到正式PyPI吗？(yes/no): ")
        if response.lower() != 'yes':
            print("❌ 取消发布")
            return
        
        self.run_command([
            sys.executable, "-m", "twine", "upload",
            "dist/*"
        ])
    
    def publish(self, test_only: bool = False, skip_tests: bool = False):
        """完整发布流程"""
        print("🎯 开始发布流程...")
        
        try:
            # 1. 检查工具
            self.check_tools()
            
            # 2. 运行测试
            if not skip_tests:
                self.run_tests()
            
            # 3. 清理构建目录
            self.clean_build_dirs()
            
            # 4. 构建包
            self.build_package()
            
            # 5. 测试安装
            self.test_install()
            
            # 6. 上传
            if test_only:
                self.upload_to_testpypi()
                print("✅ 已发布到测试PyPI")
                print("🔗 查看: https://test.pypi.org/project/docx-image-extractor-mcp/")
            else:
                # 先发布到测试环境
                try:
                    self.upload_to_testpypi()
                    print("✅ 已发布到测试PyPI")
                except subprocess.CalledProcessError as e:
                    if "already exists" in str(e.stderr):
                        print("⚠️  测试PyPI版本已存在，跳过")
                    else:
                        raise
                
                # 再发布到正式环境
                self.upload_to_pypi()
                print("🎉 发布完成！")
                print("🔗 查看: https://pypi.org/project/docx-image-extractor-mcp/")
                print("📦 安装: pip install docx-image-extractor-mcp")
            
        except Exception as e:
            print(f"❌ 发布失败: {e}")
            sys.exit(1)


def main():
    """主函数"""
    parser = argparse.ArgumentParser(description="自动化发布脚本")
    parser.add_argument("--test-only", action="store_true", help="仅发布到测试PyPI")
    parser.add_argument("--skip-tests", action="store_true", help="跳过测试")
    
    args = parser.parse_args()
    
    # 获取项目根目录
    script_dir = Path(__file__).parent
    project_root = script_dir.parent
    
    # 创建发布管理器
    publisher = PublishManager(project_root)
    
    # 执行发布
    publisher.publish(test_only=args.test_only, skip_tests=args.skip_tests)


if __name__ == "__main__":
    main()


#!/usr/bin/env python3
"""
DOC/DOCX图片提取器命令行工具
"""

import argparse
import json
import logging
import sys
from pathlib import Path
from typing import List, Optional

from ..core.extractor import extract_images, to_ascii_dirname
from ..core.config import Config, load_config


def setup_logging(level: str = "INFO") -> None:
    """设置日志"""
    logging.basicConfig(
        level=getattr(logging, level.upper()),
        format='%(asctime)s - %(name)s - %(levelname)s - %(message)s'
    )


def extract_command(args) -> None:
    """提取图片命令"""
    config = load_config(args.config) if args.config else Config()
    
    # 设置日志级别
    setup_logging(args.verbose)
    
    # 设置输出目录
    base_dir = args.output or config.base_image_dir
    
    results = []
    for doc_path in args.files:
        print(f"正在处理: {doc_path}")
        result = extract_images(doc_path, base_dir)
        results.append({
            'file': doc_path,
            'result': result
        })
        
        if result['success']:
            print(f"  ✓ 成功提取 {result['count']} 张图片到: {result['output_dir']}")
        else:
            print(f"  ✗ 失败: {result['msg']}")
    
    # 输出JSON结果
    if args.json:
        print(json.dumps(results, ensure_ascii=False, indent=2))


def preview_command(args) -> None:
    """预览DOC/DOCX结构命令"""
    import zipfile
    import olefile
    
    for doc_path in args.files:
        print(f"\n=== {doc_path} ===")
        
        try:
            if doc_path.lower().endswith('.docx'):
                # 使用python-docx预览DOCX文档结构
                try:
                    from docx import Document
                    doc = Document(doc_path)
                    print(f"段落数量: {len(doc.paragraphs)}")
                    print(f"表格数量: {len(doc.tables)}")
                except ImportError:
                    print("未安装python-docx，跳过文档结构分析")
                
                # 预览ZIP结构
                with zipfile.ZipFile(doc_path, 'r') as zf:
                    media_files = [f for f in zf.namelist() if f.startswith('word/media/')]
                    print(f"媒体文件数量: {len(media_files)}")
                    
                    if args.verbose == "DEBUG":
                        print("媒体文件列表:")
                        for media_file in media_files:
                            print(f"  - {media_file}")
                            
            elif doc_path.lower().endswith('.doc'):
                # 预览DOC文件结构
                if olefile.isOleFile(doc_path):
                    with olefile.OleFileIO(doc_path) as ole:
                        streams = ole.listdir()
                        print(f"OLE流数量: {len(streams)}")
                        
                        # 查找可能包含图片的流
                        image_streams = []
                        for stream in streams:
                            stream_name = '/'.join(stream)
                            if any(keyword in stream_name.lower() for keyword in ['data', 'objinfo', 'object', '1table', 'worddocument']):
                                image_streams.append(stream_name)
                        
                        print(f"可能包含图片的流: {len(image_streams)}")
                        
                        if args.verbose == "DEBUG":
                            print("所有流:")
                            for stream in streams:
                                print(f"  - {'/'.join(stream)}")
                else:
                    print("  ✗ 不是有效的DOC文件")
            else:
                print("  ✗ 不支持的文件格式，仅支持.doc和.docx")
                        
        except Exception as e:
            print(f"  ✗ 错误: {e}")


def convert_command(args) -> None:
    """文件名转换命令"""
    for filename in args.filenames:
        ascii_name = to_ascii_dirname(filename)
        print(f"{filename} -> {ascii_name}")


def config_command(args) -> None:
    """配置管理命令"""
    if args.action == "show":
        config = load_config(args.config) if args.config else Config()
        print(json.dumps(config._config, ensure_ascii=False, indent=2))
    
    elif args.action == "create":
        config_path = args.output or "config.json"
        config = Config()
        config.save_to_file(config_path)
        print(f"配置文件已创建: {config_path}")


def main():
    """主函数"""
    parser = argparse.ArgumentParser(
        description="DOC/DOCX图片提取器命令行工具",
        formatter_class=argparse.RawDescriptionHelpFormatter,
        epilog="""
示例用法:
  # 提取单个文件的图片
  python cli.py extract document.docx
  python cli.py extract document.doc
  
  # 提取多个文件的图片到指定目录
  python cli.py extract -o images/ doc1.docx doc2.doc
  
  # 预览文档结构
  python cli.py preview document.docx
  python cli.py preview document.doc
  
  # 转换文件名为ASCII
  python cli.py convert "测试文档.docx" "另一个文档.doc"
  
  # 显示当前配置
  python cli.py config show
        """
    )
    
    parser.add_argument(
        "-v", "--verbose",
        choices=["DEBUG", "INFO", "WARNING", "ERROR"],
        default="INFO",
        help="日志级别"
    )
    
    parser.add_argument(
        "-c", "--config",
        help="配置文件路径"
    )
    
    subparsers = parser.add_subparsers(dest="command", help="可用命令")
    
    # 提取命令
    extract_parser = subparsers.add_parser("extract", help="提取DOC/DOCX文件中的图片")
    extract_parser.add_argument("files", nargs="+", help="DOC/DOCX文件路径")
    extract_parser.add_argument("-o", "--output", help="输出目录")
    extract_parser.add_argument("--json", action="store_true", help="输出JSON格式结果")
    extract_parser.set_defaults(func=extract_command)
    
    # 预览命令
    preview_parser = subparsers.add_parser("preview", help="预览DOC/DOCX文件结构")
    preview_parser.add_argument("files", nargs="+", help="DOC/DOCX文件路径")
    preview_parser.set_defaults(func=preview_command)
    
    # 转换命令
    convert_parser = subparsers.add_parser("convert", help="转换文件名为ASCII")
    convert_parser.add_argument("filenames", nargs="+", help="要转换的文件名")
    convert_parser.set_defaults(func=convert_command)
    
    # 配置命令
    config_parser = subparsers.add_parser("config", help="配置管理")
    config_parser.add_argument(
        "action",
        choices=["show", "create"],
        help="配置操作: show(显示配置), create(创建配置文件)"
    )
    config_parser.add_argument("-o", "--output", help="输出文件路径(仅用于create)")
    config_parser.set_defaults(func=config_command)
    
    args = parser.parse_args()
    
    if not args.command:
        parser.print_help()
        sys.exit(1)
    
    try:
        args.func(args)
    except KeyboardInterrupt:
        print("\n操作已取消")
        sys.exit(1)
    except Exception as e:
        print(f"错误: {e}")
        if args.verbose == "DEBUG":
            import traceback
            traceback.print_exc()
        sys.exit(1)


if __name__ == "__main__":
    main()


"""
性能测试模块
"""

import os
import sys
import time
import tempfile
import zipfile
import unittest
from pathlib import Path

sys.path.insert(0, os.path.join(os.path.dirname(__file__), '..', 'src'))

from docx_image_extractor_mcp.core.extractor import extract_images


class TestPerformance(unittest.TestCase):
    """性能测试"""
    
    def create_test_docx(self, image_count: int = 10, image_size: int = 1024) -> str:
        """创建测试用的DOCX文件"""
        with tempfile.NamedTemporaryFile(suffix=".docx", delete=False) as tmp:
            tmp_name = tmp.name
            
        with zipfile.ZipFile(tmp_name, 'w') as zf:
            # 创建基本的DOCX结构
            zf.writestr("[Content_Types].xml", """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<Types xmlns="http://schemas.openxmlformats.org/package/2006/content-types">
    <Default Extension="rels" ContentType="application/vnd.openxmlformats-package.relationships+xml"/>
    <Default Extension="xml" ContentType="application/xml"/>
    <Override PartName="/word/document.xml" ContentType="application/vnd.openxmlformats-officedocument.wordprocessingml.document.main+xml"/>
</Types>""")
            
            zf.writestr("_rels/.rels", """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<Relationships xmlns="http://schemas.openxmlformats.org/package/2006/relationships">
    <Relationship Id="rId1" Type="http://schemas.openxmlformats.org/officeDocument/2006/relationships/officeDocument" Target="word/document.xml"/>
</Relationships>""")
            
            zf.writestr("word/document.xml", """<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<w:document xmlns:w="http://schemas.openxmlformats.org/wordprocessingml/2006/main">
    <w:body>
        <w:p><w:r><w:t>Test document</w:t></w:r></w:p>
    </w:body>
</w:document>""")
            
            # 添加测试图片
            fake_image_data = b'\x89PNG\r\n\x1a\n' + b'0' * image_size
            for i in range(image_count):
                zf.writestr(f"word/media/image{i+1}.png", fake_image_data)
        
        return tmp_name
    
    def test_small_file_performance(self):
        """测试小文件性能（10张图片）"""
        docx_path = self.create_test_docx(10, 1024)
        
        try:
            start_time = time.time()
            result = extract_images(docx_path)
            end_time = time.time()
            
            self.assertTrue(result['success'])
            self.assertEqual(result['count'], 10)
            
            processing_time = end_time - start_time
            print(f"小文件处理时间: {processing_time:.3f}秒")
            
            # 小文件应该在1秒内完成
            self.assertLess(processing_time, 1.0)
            
        finally:
            Path(docx_path).unlink(missing_ok=True)
    
    def test_medium_file_performance(self):
        """测试中等文件性能（50张图片）"""
        docx_path = self.create_test_docx(50, 2048)
        
        try:
            start_time = time.time()
            result = extract_images(docx_path)
            end_time = time.time()
            
            self.assertTrue(result['success'])
            self.assertEqual(result['count'], 50)
            
            processing_time = end_time - start_time
            print(f"中等文件处理时间: {processing_time:.3f}秒")
            
            # 中等文件应该在3秒内完成
            self.assertLess(processing_time, 3.0)
            
        finally:
            Path(docx_path).unlink(missing_ok=True)
    
    def test_large_file_performance(self):
        """测试大文件性能（100张图片）"""
        docx_path = self.create_test_docx(100, 4096)
        
        try:
            start_time = time.time()
            result = extract_images(docx_path)
            end_time = time.time()
            
            self.assertTrue(result['success'])
            self.assertEqual(result['count'], 100)
            
            processing_time = end_time - start_time
            print(f"大文件处理时间: {processing_time:.3f}秒")
            
            # 大文件应该在10秒内完成
            self.assertLess(processing_time, 10.0)
            
        finally:
            Path(docx_path).unlink(missing_ok=True)
    
    def test_memory_usage(self):
        """测试内存使用情况"""
        import psutil
        import os
        
        process = psutil.Process(os.getpid())
        initial_memory = process.memory_info().rss / 1024 / 1024  # MB
        
        # 处理多个文件
        for i in range(5):
            docx_path = self.create_test_docx(20, 2048)
            try:
                result = extract_images(docx_path)
                self.assertTrue(result['success'])
            finally:
                Path(docx_path).unlink(missing_ok=True)
        
        final_memory = process.memory_info().rss / 1024 / 1024  # MB
        memory_increase = final_memory - initial_memory
        
        print(f"内存使用: 初始 {initial_memory:.1f}MB, 最终 {final_memory:.1f}MB, 增加 {memory_increase:.1f}MB")
        
        # 内存增长应该控制在合理范围内（小于100MB）
        self.assertLess(memory_increase, 100)


if __name__ == "__main__":
    # 只有在安装了psutil的情况下才运行内存测试
    try:
        import psutil
        unittest.main()
    except ImportError:
        print("警告: 未安装psutil，跳过内存测试")
        # 运行除内存测试外的其他测试
        suite = unittest.TestLoader().loadTestsFromTestCase(TestPerformance)
        filtered_suite = unittest.TestSuite()
        for test in suite:
            if "memory" not in test._testMethodName:
                filtered_suite.addTest(test)
        unittest.TextTestRunner().run(filtered_suite)


"""
DOCX Image Extractor MCP

一个功能强大的DOCX图片提取器，支持MCP协议，可与Claude Desktop等AI工具集成。

主要功能：
- 从Word文档中提取所有图片
- 自动检测图片格式
- 支持中文文档名转拼音
- 提供MCP协议接口
- 支持配置文件自定义
"""

__version__ = "1.1.0"
__author__ = "DOCX Image Extractor Team"
__email__ = "contact@example.com"

from .core.extractor import extract_images, to_ascii_dirname
from .interfaces.mcp_server import DocxImageExtractorMCP
from .core.config import config, Config, load_config

__all__ = [
    "extract_images",
    "to_ascii_dirname", 
    "DocxImageExtractorMCP",
    "config",
    "Config",
    "load_config",
]


#!/usr/bin/env python3
"""
DOCX Image Extractor MCP - Setup Script
"""

from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="docx-image-extractor-mcp",
    version="1.2.1",
    author="DOCX Image Extractor Team",
    author_email="docx.extractor@gmail.com",
    description="A powerful DOC/DOCX image extractor with MCP protocol support for Claude Desktop integration",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/docx-image-extractor/docx-image-extractor-mcp",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    python_requires=">=3.8",
    install_requires=[
        "pypinyin>=0.47.0",
        "mcp>=1.0.0",
        "python-docx>=0.8.11",
        "olefile>=0.46",
        "docx2txt>=0.8",
    ],
    entry_points={
        "console_scripts": [
            "docx-image-extractor-mcp=docx_image_extractor_mcp.main:cli_main",
            "docx-extract=docx_image_extractor_mcp.cli:main",
        ],
    },
    keywords="doc, docx, image, extractor, mcp, word, document, ole",
    project_urls={
        "Bug Reports": "https://github.com/docx-image-extractor/docx-image-extractor-mcp/issues",
        "Source": "https://github.com/docx-image-extractor/docx-image-extractor-mcp",
        "Documentation": "https://github.com/docx-image-extractor/docx-image-extractor-mcp/blob/main/README.md",
        "Changelog": "https://github.com/docx-image-extractor/docx-image-extractor-mcp/blob/main/CHANGELOG.md",
    },
)


"""
DOCX图片提取器核心模块
"""

import os
import os
import zipfile
import logging
import struct
from pathlib import Path
from typing import Dict, Union

try:
    from pypinyin import lazy_pinyin
except ImportError:
    raise ImportError("需要安装 pypinyin 库: pip install pypinyin")

try:
    import olefile
except ImportError:
    raise ImportError("需要安装 olefile 库: pip install olefile")

# 配置日志
logger = logging.getLogger(__name__)


def to_ascii_dirname(name: str) -> str:
    """
    文档名转英文目录（中文转拼音，去除非字母数字，全小写）
    
    Args:
        name: 文档名称
        
    Returns:
        转换后的英文目录名
    """
    if not name:
        return ""
    
    # 特殊处理：如果文件名以点开头（如 .docx），返回空字符串
    if name.startswith('.'):
        return ""
    
    # 获取文件名（不含扩展名）
    stem = Path(name).stem
    if not stem:  # 如果只有扩展名，返回空字符串
        return ""
    
    # 转换为拼音并转小写
    pinyin_name = ''.join(lazy_pinyin(stem)).lower()
    # 只保留字母和数字
    result = ''.join(ch for ch in pinyin_name if ch.isalnum())
    
    return result


def extract_images(doc_path: str, base_image_dir: str = 'images') -> Dict[str, Union[bool, str, int]]:
    """
    提取 docx 或 doc 所有图片到 base_image_dir/文档英文名/ 下
    
    Args:
        doc_path: Word文档的完整路径（支持 .docx 和 .doc）
        base_image_dir: 图片保存的根目录名（默认：'images'）
        
    Returns:
        包含提取结果的字典，格式：
        {
            'success': bool,
            'msg': str,
            'output_dir': str,
            'count': int,
            'skipped': int (可选)
        }
    """
    logger.info(f"开始提取图片: {doc_path}")
    
    # 路径标准化
    doc_path = os.path.abspath(doc_path)
    base_image_dir = os.path.abspath(base_image_dir)
    
    # 验证输入
    if not os.path.exists(doc_path):
        error_msg = f'文档不存在: {doc_path}'
        logger.error(error_msg)
        return {'success': False, 'msg': error_msg, 'output_dir': '', 'count': 0}
    
    file_ext = doc_path.lower()
    if not (file_ext.endswith('.docx') or file_ext.endswith('.doc')):
        error_msg = '只支持.docx和.doc文件'
        logger.error(error_msg)
        return {'success': False, 'msg': error_msg, 'output_dir': '', 'count': 0}
    
    # 创建输出目录
    doc_dir = to_ascii_dirname(doc_path)
    out_dir = os.path.join(base_image_dir, doc_dir)
    logger.info(f"输出目录: {out_dir}")
    
    try:
        os.makedirs(out_dir, exist_ok=True)
    except Exception as e:
        error_msg = f'创建目录失败: {str(e)}'
        logger.error(error_msg)
        return {'success': False, 'msg': error_msg, 'output_dir': out_dir, 'count': 0}
    
    # 根据文件类型选择处理方式
    if file_ext.endswith('.docx'):
        return _extract_from_docx(doc_path, out_dir)
    elif file_ext.endswith('.doc'):
        return _extract_from_doc(doc_path, out_dir)
    else:
        error_msg = '不支持的文件格式'
        logger.error(error_msg)
        return {'success': False, 'msg': error_msg, 'output_dir': out_dir, 'count': 0}


def _extract_from_docx(docx_path: str, out_dir: str) -> Dict[str, Union[bool, str, int]]:
    """
    从 DOCX 文件中提取图片
    
    Args:
        docx_path: DOCX文件路径
        out_dir: 输出目录
        
    Returns:
        提取结果字典
    """
    count = 0
    skipped = 0
    extracted_files = []
    
    try:
        with zipfile.ZipFile(docx_path, 'r') as zip_ref:
            # 查找所有媒体文件
            media_files = [f for f in zip_ref.namelist() 
                          if f.startswith('word/media/') and not f.endswith('/')]
            
            if not media_files:
                msg = '文档中未找到任何图片'
                logger.warning(msg)
                return {
                    'success': False, 
                    'msg': msg,
                    'output_dir': out_dir,
                    'count': 0
                }
            
            logger.info(f"找到 {len(media_files)} 个媒体文件")
            
            for i, media_file in enumerate(media_files):
                ext = os.path.splitext(media_file)[-1].lower()
                # 如果没有扩展名，尝试从文件内容判断
                if not ext:
                    ext = _detect_image_format(zip_ref, media_file)
                
                out_file = os.path.join(out_dir, f'image_{i+1:03d}{ext}')
                
                try:
                    with zip_ref.open(media_file) as src:
                        data = src.read()
                        if data and len(data) > 0:  # 确保有数据才写入
                            with open(out_file, 'wb') as dst:
                                dst.write(data)
                            count += 1
                            extracted_files.append(out_file)
                            logger.debug(f"提取: {media_file} -> {out_file}")
                        else:
                            logger.warning(f"跳过空文件: {media_file}")
                            skipped += 1
                except Exception as e:
                    logger.warning(f"提取 {media_file} 失败: {str(e)}")
                    skipped += 1
                    # 删除可能创建的空文件
                    if os.path.exists(out_file):
                        os.remove(out_file)
                    continue
                    
    except zipfile.BadZipFile:
        error_msg = f'无效的DOCX文件: {docx_path}'
        logger.error(error_msg)
        return {'success': False, 'msg': error_msg, 'output_dir': out_dir, 'count': 0}
    except Exception as e:
        error_msg = f'提取失败: {str(e)}'
        logger.error(error_msg)
        return {'success': False, 'msg': error_msg, 'output_dir': out_dir, 'count': 0}
    
    # 构建结果
    result = {
        'success': count > 0,
        'output_dir': out_dir,
        'count': count
    }
    
    if count > 0:
        msg = f'成功提取 {count} 个图片到: {out_dir}'
        if skipped > 0:
            msg += f'，跳过 {skipped} 个无效文件'
            result['skipped'] = skipped
        logger.info(msg)
        result['msg'] = msg
    else:
        msg = f'未找到任何有效图片，跳过 {skipped} 个无效文件'
        logger.warning(msg)
        result['msg'] = msg
        result['skipped'] = skipped
    
    return result


def _extract_from_doc(doc_path: str, out_dir: str) -> Dict[str, Union[bool, str, int]]:
    """
    从 DOC 文件中提取图片
    
    Args:
        doc_path: DOC文件路径
        out_dir: 输出目录
        
    Returns:
        提取结果字典
    """
    count = 0
    skipped = 0
    
    try:
        # 检查是否为有效的 OLE 文件
        if not olefile.isOleFile(doc_path):
            error_msg = f'无效的DOC文件: {doc_path}'
            logger.error(error_msg)
            return {'success': False, 'msg': error_msg, 'output_dir': out_dir, 'count': 0}
        
        with olefile.OleFileIO(doc_path) as ole:
            # 查找所有流
            streams = ole.listdir()
            logger.info(f"找到 {len(streams)} 个流")
            
            # 查找包含图片数据的流
            image_streams = []
            for stream in streams:
                stream_name = '/'.join(stream)
                # 查找可能包含图片的流
                if any(keyword in stream_name.lower() for keyword in ['data', 'objinfo', 'object', '1table', 'worddocument']):
                    try:
                        data = ole.openfile(stream).read()
                        # 在数据中查找图片标识符
                        images = _find_images_in_data(data)
                        if images:
                            image_streams.extend(images)
                            logger.debug(f"在流 {stream_name} 中找到 {len(images)} 个图片")
                    except Exception as e:
                        logger.debug(f"读取流 {stream_name} 失败: {str(e)}")
                        continue
            
            if not image_streams:
                msg = '文档中未找到任何图片'
                logger.warning(msg)
                return {
                    'success': False, 
                    'msg': msg,
                    'output_dir': out_dir,
                    'count': 0
                }
            
            logger.info(f"找到 {len(image_streams)} 个图片")
            
            # 保存图片
            for i, image_data in enumerate(image_streams):
                try:
                    # 检测图片格式
                    ext = _detect_image_format_from_data(image_data)
                    out_file = os.path.join(out_dir, f'image_{i+1:03d}{ext}')
                    
                    if len(image_data) > 0:  # 确保有数据才写入
                        with open(out_file, 'wb') as f:
                            f.write(image_data)
                        count += 1
                        logger.debug(f"保存图片: {out_file}")
                    else:
                        logger.warning(f"跳过空图片数据")
                        skipped += 1
                except Exception as e:
                    logger.warning(f"保存图片 {i+1} 失败: {str(e)}")
                    skipped += 1
                    continue
                    
    except Exception as e:
        error_msg = f'提取DOC文件失败: {str(e)}'
        logger.error(error_msg)
        return {'success': False, 'msg': error_msg, 'output_dir': out_dir, 'count': 0}
    
    # 构建结果
    result = {
        'success': count > 0,
        'output_dir': out_dir,
        'count': count
    }
    
    if count > 0:
        msg = f'成功提取 {count} 个图片到: {out_dir}'
        if skipped > 0:
            msg += f'，跳过 {skipped} 个无效文件'
            result['skipped'] = skipped
        logger.info(msg)
        result['msg'] = msg
    else:
        msg = f'未找到任何有效图片，跳过 {skipped} 个无效文件'
        logger.warning(msg)
        result['msg'] = msg
        result['skipped'] = skipped
    
    return result


def _find_images_in_data(data: bytes) -> list:
    """
    在二进制数据中查找图片
    
    Args:
        data: 二进制数据
        
    Returns:
        图片数据列表
    """
    images = []
    
    # 常见图片格式的文件头
    image_headers = [
        (b'\xff\xd8\xff', b'\xff\xd9'),  # JPEG
        (b'\x89PNG\r\n\x1a\n', b'IEND\xaeB`\x82'),  # PNG
        (b'GIF8', b'\x00;'),  # GIF
        (b'BM', None),  # BMP (没有固定结尾)
        (b'RIFF', b'WEBP'),  # WEBP
    ]
    
    for start_marker, end_marker in image_headers:
        pos = 0
        while True:
            # 查找开始标记
            start_pos = data.find(start_marker, pos)
            if start_pos == -1:
                break
                
            if end_marker:
                # 查找结束标记
                end_pos = data.find(end_marker, start_pos + len(start_marker))
                if end_pos != -1:
                    end_pos += len(end_marker)
                    image_data = data[start_pos:end_pos]
                    if len(image_data) > 100:  # 过滤太小的数据
                        images.append(image_data)
                    pos = end_pos
                else:
                    break
            else:
                # BMP 格式特殊处理
                if start_marker == b'BM':
                    try:
                        # BMP 文件头包含文件大小信息
                        if start_pos + 6 < len(data):
                            file_size = struct.unpack('<I', data[start_pos+2:start_pos+6])[0]
                            if start_pos + file_size <= len(data) and file_size > 100:
                                image_data = data[start_pos:start_pos+file_size]
                                images.append(image_data)
                        pos = start_pos + 1
                    except:
                        pos = start_pos + 1
                else:
                    pos = start_pos + 1
    
    return images


def _detect_image_format_from_data(data: bytes) -> str:
    """
    通过数据头检测图片格式
    
    Args:
        data: 图片二进制数据
        
    Returns:
        文件扩展名
    """
    if len(data) < 8:
        return '.png'
        
    # 检测常见图片格式
    if data.startswith(b'\x89PNG'):
        return '.png'
    elif data.startswith(b'\xff\xd8\xff'):
        return '.jpg'
    elif data.startswith(b'GIF8'):
        return '.gif'
    elif data.startswith(b'BM'):
        return '.bmp'
    elif data.startswith(b'RIFF') and b'WEBP' in data[:12]:
        return '.webp'
    else:
        return '.png'  # 默认使用PNG


def _detect_image_format(zip_ref: zipfile.ZipFile, media_file: str) -> str:
    """
    通过文件头检测图片格式
    
    Args:
        zip_ref: ZIP文件引用
        media_file: 媒体文件路径
        
    Returns:
        文件扩展名
    """
    try:
        with zip_ref.open(media_file) as f:
            header = f.read(8)
            
        # 检测常见图片格式
        if header.startswith(b'\x89PNG'):
            return '.png'
        elif header.startswith(b'\xff\xd8\xff'):
            return '.jpg'
        elif header.startswith(b'GIF8'):
            return '.gif'
        elif header.startswith(b'BM'):
            return '.bmp'
        elif header.startswith(b'RIFF') and b'WEBP' in header:
            return '.webp'
        else:
            return '.png'  # 默认使用PNG
    except Exception:
        return '.png'  # 出错时默认使用PNG